import React from "react";
import EventIcon from "@mui/icons-material/Event";
import AccessTimeIcon from "@mui/icons-material/AccessTime";
import { Stack, Tooltip } from "@mui/material";
import { formatDate, timeAgo } from "../../common/Helper";
import LabeledIcon from "../../common/LabeledIcon";
import moment from "moment";
import { JobStatusIcon } from "../JobStatus";

const formattedDuration = ({ startDate, finishDate }) => {
  if (startDate && finishDate) {
    return moment
      .utc(finishDate.getTime() - startDate.getTime())
      .format("HH:mm:ss");
  } else {
    return null;
  }
};

export const JobStatusColumn = ({ job }) => {
  const createOrStartDate = new Date(job?.startTime ?? job.createdAt);
  const formattedCreateOrStartDate = `${
    job?.startTime ? "Started" : "Created"
  } ${timeAgo.format(new Date(createOrStartDate))}`;

  const duration = formattedDuration({
    finishDate: new Date(job.finishedAt),
    startDate: new Date(createOrStartDate)
  });

  return (
    <Stack>
      <Stack gap={0.5}>
        <JobStatusIcon job={job} />
        <Stack>
          <Tooltip
            title={`${formatDate(createOrStartDate)}`}
            aria-label={`${formattedCreateOrStartDate}, on ${formatDate(
              createOrStartDate
            )}`}
          >
            <LabeledIcon
              label={formattedCreateOrStartDate}
              LabelProps={{ variant: "body2" }}
              labelPosition="right"
              Icon={EventIcon}
              IconProps={{ fontSize: "small" }}
            />
          </Tooltip>
          {job?.finishedAt ? (
            <Tooltip
              title={`Finished ${job.finishedAt}`}
              aria-label={`Finshed ${job.finishedAt}, after ${duration}`}
            >
              <LabeledIcon
                label={`${duration}`}
                LabelProps={{ variant: "body2" }}
                labelPosition="right"
                Icon={AccessTimeIcon}
                IconProps={{ fontSize: "small" }}
              />
            </Tooltip>
          ) : null}
        </Stack>
      </Stack>
    </Stack>
  );
};
